==> javacs-protocol-0.0.5-sources.jar: org/javacs/lsp/LanguageServer.java <==
package org.javacs.lsp;

import java.util.List;
import java.util.Optional;

public interface LanguageServer {
  @LspRequest("initialize")
  default InitializeResult initialize(InitializeParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspNotification("initialized")
  default void initialized() {}

  @LspRequest("shutdown")
  default Object shutdown() {
    return null;
  }

  @LspNotification("exit")
  default void exit() {}

  @LspNotification("workspace/didChangeConfiguration")
  default void didChangeConfiguration(DidChangeConfigurationParams params) {}

  @LspNotification("textDocument/didOpen")
  default void didOpenTextDocument(DidOpenTextDocumentParams params) {}

  @LspNotification("textDocument/didChange")
  default void didChangeTextDocument(DidChangeTextDocumentParams params) {}

  @LspNotification("textDocument/willSave")
  default void willSaveTextDocument(WillSaveTextDocumentParams params) {}

  @LspRequest("textDocument/willSaveWaitUntil")
  default List<TextEdit> willSaveWaitUntilTextDocument(WillSaveTextDocumentParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspNotification("textDocument/didSave")
  default void didSaveTextDocument(DidSaveTextDocumentParams params) {}

  @LspNotification("textDocument/didClose")
  default void didCloseTextDocument(DidCloseTextDocumentParams params) {}

  @LspNotification("workspace/didChangeWatchedFiles")
  default void didChangeWatchedFiles(DidChangeWatchedFilesParams params) {}

  @LspRequest("textDocument/completion")
  default Optional<CompletionList> completion(TextDocumentPositionParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("completionItem/resolve")
  default CompletionItem resolveCompletionItem(CompletionItem params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/hover")
  default Optional<Hover> hover(TextDocumentPositionParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/signatureHelp")
  default Optional<SignatureHelp> signatureHelp(TextDocumentPositionParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/definition")
  default Optional<List<? extends GenericLocation>> gotoDefinition(TextDocumentPositionParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/references")
  default Optional<List<Location>> findReferences(ReferenceParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/documentSymbol")
  default List<? extends GenericDocumentSymbol> documentSymbol(DocumentSymbolParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("workspace/symbol")
  default List<? extends GenericWorkspaceSymbol> workspaceSymbols(WorkspaceSymbolParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/codeAction")
  default List<CodeAction> codeAction(CodeActionParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/codeLens")
  default List<CodeLens> codeLens(CodeLensParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("codeLens/resolve")
  default CodeLens resolveCodeLens(CodeLens params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/prepareRename")
  default Optional<RenameResponse> prepareRename(TextDocumentPositionParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/rename")
  default WorkspaceEdit rename(RenameParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspNotification("workspace/didChangeWorkspaceFolders")
  default void didChangeWorkspaceFolders(DidChangeWorkspaceFoldersParams params) {}

  @LspRequest("textDocument/formatting")
  default List<TextEdit> formatting(DocumentFormattingParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/foldingRange")
  default List<FoldingRange> foldingRange(FoldingRangeParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/documentLink")
  default List<DocumentLink> documentLink(DocumentLinkParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/documentHighlight")
  default List<DocumentHighlight> documentHighlight(TextDocumentPositionParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  @LspRequest("textDocument/inlayHint")
  default List<InlayHint> inlayHint(InlayHintParams params) {
    throw new UnsupportedOperationException("Unimplemented");
  }

  default void doAsyncWork() {}
}

==> javacs-protocol-0.0.18-sources.jar: org/javacs/lsp/LanguageServer.java <==
package org.javacs.lsp;

import java.util.List;
import java.util.Optional;

public interface LanguageServer {
  @LspRequest("initialize")
  InitializeResult initialize(InitializeParams params);

  @LspNotification("initialized")
  default void initialized() {}

  @LspRequest("shutdown")
  default Object shutdown() {
    return null;
  }

  @LspNotification("exit")
  default void exit() {}

  @LspNotification("workspace/didChangeConfiguration")
  default void didChangeConfiguration(DidChangeConfigurationParams params) {}

  @LspNotification("textDocument/didOpen")
  default void didOpenTextDocument(DidOpenTextDocumentParams params) {}

  @LspNotification("textDocument/didChange")
  default void didChangeTextDocument(DidChangeTextDocumentParams params) {}

  @LspNotification("textDocument/willSave")
  default void willSaveTextDocument(WillSaveTextDocumentParams params) {}

  @LspRequest("textDocument/willSaveWaitUntil")
  List<TextEdit> willSaveWaitUntilTextDocument(WillSaveTextDocumentParams params);

  @LspNotification("textDocument/didSave")
  default void didSaveTextDocument(DidSaveTextDocumentParams params) {}

  @LspNotification("textDocument/didClose")
  default void didCloseTextDocument(DidCloseTextDocumentParams params) {}

  @LspNotification("workspace/didChangeWatchedFiles")
  default void didChangeWatchedFiles(DidChangeWatchedFilesParams params) {}

  @LspRequest("textDocument/completion")
  Optional<CompletionList> completion(TextDocumentPositionParams params);

  @LspRequest("completionItem/resolve")
  CompletionItem resolveCompletionItem(CompletionItem params);

  @LspRequest("textDocument/hover")
  Optional<Hover> hover(TextDocumentPositionParams params);

  @LspRequest("textDocument/signatureHelp")
  Optional<SignatureHelp> signatureHelp(TextDocumentPositionParams params);

  @LspRequest("textDocument/definition")
  Optional<List<? extends GenericLocation>> gotoDefinition(TextDocumentPositionParams params);

  @LspRequest("textDocument/references")
  Optional<List<Location>> findReferences(ReferenceParams params);

  @LspRequest("textDocument/documentSymbol")
  List<? extends GenericDocumentSymbol> documentSymbol(DocumentSymbolParams params);

  @LspRequest("workspace/symbol")
  List<? extends GenericWorkspaceSymbol> workspaceSymbols(WorkspaceSymbolParams params);

  @LspRequest("textDocument/codeAction")
  List<CodeAction> codeAction(CodeActionParams params);

  @LspRequest("textDocument/codeLens")
  List<CodeLens> codeLens(CodeLensParams params);

  @LspRequest("codeLens/resolve")
  CodeLens resolveCodeLens(CodeLens params);

  @LspRequest("textDocument/prepareRename")
  Optional<RenameResponse> prepareRename(TextDocumentPositionParams params);

  @LspRequest("textDocument/rename")
  WorkspaceEdit rename(RenameParams params);

  @LspNotification("workspace/didChangeWorkspaceFolders")
  default void didChangeWorkspaceFolders(DidChangeWorkspaceFoldersParams params) {}

  @LspRequest("textDocument/formatting")
  List<TextEdit> formatting(DocumentFormattingParams params);

  @LspRequest("textDocument/foldingRange")
  List<FoldingRange> foldingRange(FoldingRangeParams params);

  @LspRequest("textDocument/documentLink")
  List<DocumentLink> documentLink(DocumentLinkParams params);

  @LspRequest("textDocument/documentHighlight")
  List<DocumentHighlight> documentHighlight(TextDocumentPositionParams params);

  @LspRequest("textDocument/inlayHint")
  List<InlayHint> inlayHint(InlayHintParams params);

  default void doAsyncWork() {}
}
